@@ -29,14 +29,21 @@ GtkWidget *xfbd;
 GtkWidget *preview_pixmap_frame;
 GtkWidget *preview_pixmap;
 GtkWidget *filename_entry;
+GtkWidget *setup_tiled;
+GtkWidget *setup_stretched;
+GtkWidget *setup_auto;
 
 char *backdrp;
+char *istiled;
+char *filename;
 
-int setroot (char *str);
-void readstr (char *str);
-int writestr (char *str);
+int setroot (char *str, char *tiled);
+void readstr (char *str, char *tiled);
+int writestr (char *str, char *tiled);
 void display_back (char *str);
 
+void select_backdrp (char *, char *);
+
 GtkWidget *create_xfbd ();
 
 #endif
