@@ -29,6 +29,7 @@
 #include "my_intl.h"
 #include "xfce_main.h"
 #include "xfce-common.h"
+#include "configfile.h"
 #include "selects.h"
 #include "action.h"
 #include "action_cb.h"
@@ -63,17 +64,22 @@ create_action (void)
   gtk_window_set_title (GTK_WINDOW (action), _("Define action ..."));
   gtk_window_position (GTK_WINDOW (action), GTK_WIN_POS_CENTER);
   gtk_widget_realize (action);
-
+  /*
+     gnome_layer (action->window, MAX_LAYERS);
+   */
   accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (action), accel_group);
 
   action_mainframe = gtk_frame_new (NULL);
   gtk_widget_set_name (action_mainframe, "action_mainframe");
-  gtk_object_set_data (GTK_OBJECT (action), "action_mainframe",
-		       action_mainframe);
+  gtk_object_set_data (GTK_OBJECT (action), "action_mainframe", action_mainframe);
   gtk_widget_show (action_mainframe);
   gtk_container_add (GTK_CONTAINER (action), action_mainframe);
+#ifdef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (action_mainframe), GTK_SHADOW_NONE);
+#else
   gtk_frame_set_shadow_type (GTK_FRAME (action_mainframe), GTK_SHADOW_OUT);
+#endif
 
   action_vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_set_name (action_vbox, "action_vbox");
@@ -89,8 +95,7 @@ create_action (void)
 
   actopn_topframe = gtk_frame_new (NULL);
   gtk_widget_set_name (actopn_topframe, "actopn_topframe");
-  gtk_object_set_data (GTK_OBJECT (action), "actopn_topframe",
-		       actopn_topframe);
+  gtk_object_set_data (GTK_OBJECT (action), "actopn_topframe", actopn_topframe);
   gtk_widget_show (actopn_topframe);
   gtk_box_pack_start (GTK_BOX (action_hbox), actopn_topframe, TRUE, TRUE, 0);
   gtk_container_border_width (GTK_CONTAINER (actopn_topframe), 5);
@@ -103,98 +108,71 @@ create_action (void)
 
   action_command_label = gtk_label_new (_("Command Line :"));
   gtk_widget_set_name (action_command_label, "action_command_label");
-  gtk_object_set_data (GTK_OBJECT (action), "action_command_label",
-		       action_command_label);
+  gtk_object_set_data (GTK_OBJECT (action), "action_command_label", action_command_label);
   gtk_widget_show (action_command_label);
-  gtk_table_attach (GTK_TABLE (action_table), action_command_label, 0, 1, 0,
-		    1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_command_label, 0, 1, 0, 1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_label_set_justify (GTK_LABEL (action_command_label), GTK_JUSTIFY_RIGHT);
   gtk_misc_set_alignment (GTK_MISC (action_command_label), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (action_command_label), 10, 0);
 
   action_icon_label = gtk_label_new (_("Icon Style :"));
   gtk_widget_set_name (action_icon_label, "action_icon_label");
-  gtk_object_set_data (GTK_OBJECT (action), "action_icon_label",
-		       action_icon_label);
+  gtk_object_set_data (GTK_OBJECT (action), "action_icon_label", action_icon_label);
   gtk_widget_show (action_icon_label);
-  gtk_table_attach (GTK_TABLE (action_table), action_icon_label, 0, 1, 1, 2,
-		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_icon_label, 0, 1, 1, 2, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_label_set_justify (GTK_LABEL (action_icon_label), GTK_JUSTIFY_RIGHT);
   gtk_misc_set_alignment (GTK_MISC (action_icon_label), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (action_icon_label), 10, 0);
 
   action_command_entry = gtk_entry_new ();
   gtk_widget_set_name (action_command_entry, "action_command_entry");
-  gtk_object_set_data (GTK_OBJECT (action), "action_command_entry",
-		       action_command_entry);
+  gtk_object_set_data (GTK_OBJECT (action), "action_command_entry", action_command_entry);
   gtk_widget_show (action_command_entry);
-  gtk_table_attach (GTK_TABLE (action_table), action_command_entry, 1, 2, 0,
-		    1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_command_entry, 1, 2, 0, 1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
 
   action_icon_optionmenu = gtk_option_menu_new ();
   gtk_widget_set_name (action_icon_optionmenu, "action_icon_optionmenu");
-  gtk_object_set_data (GTK_OBJECT (action), "action_icon_optionmenu",
-		       action_icon_optionmenu);
+  gtk_object_set_data (GTK_OBJECT (action), "action_icon_optionmenu", action_icon_optionmenu);
   gtk_widget_show (action_icon_optionmenu);
-  gtk_table_attach (GTK_TABLE (action_table), action_icon_optionmenu, 1, 2, 1,
-		    2, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_icon_optionmenu, 1, 2, 1, 2, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
   action_icon_optionmenu_menu = gtk_menu_new ();
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (action_icon_optionmenu),
-			    action_icon_optionmenu_menu);
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (action_icon_optionmenu), action_icon_optionmenu_menu);
 
   action_icon_browse_button = gtk_button_new_with_label (_("Browse ..."));
-  gtk_widget_set_name (action_icon_browse_button,
-		       "action_icon_browse_button");
-  gtk_object_set_data (GTK_OBJECT (action), "action_icon_browse_button",
-		       action_icon_browse_button);
+  gtk_widget_set_name (action_icon_browse_button, "action_icon_browse_button");
+  gtk_object_set_data (GTK_OBJECT (action), "action_icon_browse_button", action_icon_browse_button);
   gtk_widget_show (action_icon_browse_button);
-  gtk_table_attach (GTK_TABLE (action_table), action_icon_browse_button, 2, 3,
-		    1, 2, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_icon_browse_button, 2, 3, 1, 2, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
   gtk_widget_set_usize (action_icon_browse_button, 90, -2);
   gtk_container_border_width (GTK_CONTAINER (action_icon_browse_button), 5);
   GTK_WIDGET_SET_FLAGS (action_icon_browse_button, GTK_CAN_DEFAULT);
 
   action_command_browse_button = gtk_button_new_with_label (_("Browse ..."));
-  gtk_widget_set_name (action_command_browse_button,
-		       "action_command_browse_button");
-  gtk_object_set_data (GTK_OBJECT (action), "action_command_browse_button",
-		       action_command_browse_button);
+  gtk_widget_set_name (action_command_browse_button, "action_command_browse_button");
+  gtk_object_set_data (GTK_OBJECT (action), "action_command_browse_button", action_command_browse_button);
   gtk_widget_show (action_command_browse_button);
-  gtk_table_attach (GTK_TABLE (action_table), action_command_browse_button, 2,
-		    3, 0, 1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
-		    (GtkAttachOptions) GTK_EXPAND, 0, 0);
+  gtk_table_attach (GTK_TABLE (action_table), action_command_browse_button, 2, 3, 0, 1, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
   gtk_widget_set_usize (action_command_browse_button, 90, -2);
-  gtk_container_border_width (GTK_CONTAINER (action_command_browse_button),
-			      5);
+  gtk_container_border_width (GTK_CONTAINER (action_command_browse_button), 5);
   GTK_WIDGET_SET_FLAGS (action_command_browse_button, GTK_CAN_DEFAULT);
 
   action_bottom_frame = gtk_frame_new (NULL);
   gtk_widget_set_name (action_bottom_frame, "action_bottom_frame");
-  gtk_object_set_data (GTK_OBJECT (action), "action_bottom_frame",
-		       action_bottom_frame);
+  gtk_object_set_data (GTK_OBJECT (action), "action_bottom_frame", action_bottom_frame);
   gtk_widget_show (action_bottom_frame);
-  gtk_box_pack_start (GTK_BOX (action_vbox), action_bottom_frame, FALSE, TRUE,
-		      0);
+  gtk_box_pack_start (GTK_BOX (action_vbox), action_bottom_frame, FALSE, TRUE, 0);
   gtk_container_border_width (GTK_CONTAINER (action_bottom_frame), 5);
 
   action_hbuttonbox = gtk_hbutton_box_new ();
   gtk_widget_set_name (action_hbuttonbox, "action_hbuttonbox");
-  gtk_object_set_data (GTK_OBJECT (action), "action_hbuttonbox",
-		       action_hbuttonbox);
+  gtk_object_set_data (GTK_OBJECT (action), "action_hbuttonbox", action_hbuttonbox);
   gtk_widget_show (action_hbuttonbox);
   gtk_container_add (GTK_CONTAINER (action_bottom_frame), action_hbuttonbox);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (action_hbuttonbox),
-			     GTK_BUTTONBOX_SPREAD);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (action_hbuttonbox), GTK_BUTTONBOX_SPREAD);
 
   action_ok_button = gtk_button_new_with_label (_("Ok"));
   gtk_widget_set_name (action_ok_button, "action_ok_button");
-  gtk_object_set_data (GTK_OBJECT (action), "action_ok_button",
-		       action_ok_button);
+  gtk_object_set_data (GTK_OBJECT (action), "action_ok_button", action_ok_button);
   gtk_widget_show (action_ok_button);
   gtk_container_add (GTK_CONTAINER (action_hbuttonbox), action_ok_button);
   gtk_container_border_width (GTK_CONTAINER (action_ok_button), 5);
@@ -203,33 +181,24 @@ create_action (void)
 
   action_cancel_button = gtk_button_new_with_label (_("Cancel"));
   gtk_widget_set_name (action_cancel_button, "action_cancel_button");
-  gtk_object_set_data (GTK_OBJECT (action), "action_cancel_button",
-		       action_cancel_button);
+  gtk_object_set_data (GTK_OBJECT (action), "action_cancel_button", action_cancel_button);
   gtk_widget_show (action_cancel_button);
   gtk_container_add (GTK_CONTAINER (action_hbuttonbox), action_cancel_button);
   gtk_container_border_width (GTK_CONTAINER (action_cancel_button), 5);
   GTK_WIDGET_SET_FLAGS (action_cancel_button, GTK_CAN_DEFAULT);
 
-  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group,
-			      GDK_Return, 0, GTK_ACCEL_VISIBLE);
-  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group,
-			      GDK_Return, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group,
-			      GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group, GDK_Return, 0, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group, GDK_Return, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (action_ok_button, "clicked", accel_group, GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
-  gtk_widget_add_accelerator (action_cancel_button, "clicked", accel_group,
-			      GDK_Escape, 0, GTK_ACCEL_VISIBLE);
-  gtk_widget_add_accelerator (action_cancel_button, "clicked", accel_group,
-			      GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (action_cancel_button, "clicked", accel_group, GDK_Escape, 0, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (action_cancel_button, "clicked", accel_group, GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
-  gtk_signal_connect (GTK_OBJECT (action), "delete_event",
-		      GTK_SIGNAL_FUNC (action_delete_event), NULL);
+  gtk_signal_connect (GTK_OBJECT (action), "delete_event", GTK_SIGNAL_FUNC (action_delete_event), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (action_cancel_button), "clicked",
-		      GTK_SIGNAL_FUNC (action_cancel_cb), NULL);
+  gtk_signal_connect (GTK_OBJECT (action_cancel_button), "clicked", GTK_SIGNAL_FUNC (action_cancel_cb), NULL);
 
-  gtk_signal_connect (GTK_OBJECT (action_command_browse_button), "clicked",
-		      GTK_SIGNAL_FUNC (action_browse_command_cb), NULL);
+  gtk_signal_connect (GTK_OBJECT (action_command_browse_button), "clicked", GTK_SIGNAL_FUNC (action_browse_command_cb), NULL);
 
   init_choice_str ();
 
@@ -239,7 +208,7 @@ create_action (void)
 void
 private_action_update_menuentry_cb (GtkWidget * widget, gpointer data)
 {
-  private_action_menu_selected = (gint)((long) data);
+  private_action_menu_selected = (gint) ((long) data);
 }
 
 GtkWidget *
@@ -249,16 +218,13 @@ action_addto_choice (char *name)
   GtkWidget *menuitem = NULL;
 
   if (name && strlen (name))
-    {
-      menuitem = gtk_menu_item_new_with_label (name);
-      gtk_menu_append (GTK_MENU (action_icon_optionmenu_menu), menuitem);
-      gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			  GTK_SIGNAL_FUNC
-			  (private_action_update_menuentry_cb),
-			  (gpointer)((long) position++));
-      gtk_widget_show (menuitem);
-      gtk_widget_realize (menuitem);
-    }
+  {
+    menuitem = gtk_menu_item_new_with_label (name);
+    gtk_menu_append (GTK_MENU (action_icon_optionmenu_menu), menuitem);
+    gtk_signal_connect (GTK_OBJECT (menuitem), "activate", GTK_SIGNAL_FUNC (private_action_update_menuentry_cb), (gpointer) ((long) position++));
+    gtk_widget_show (menuitem);
+    gtk_widget_realize (menuitem);
+  }
   return menuitem;
 }
 
@@ -271,40 +237,37 @@ action_get_choice_selected (void)
 void
 action_set_choice_selected (gint index)
 {
-  gtk_option_menu_set_history (GTK_OPTION_MENU (action_icon_optionmenu),
-			       index);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (action_icon_optionmenu), index);
   private_action_menu_selected = index;
 }
 
 void
 open_action (GtkWidget * action, gint nbr)
 {
+  /* Return if DISABLE_XFCE_USER_CONFIG was set */
+  if (current_config.disable_user_config)
+    return;
+    
   if (!GTK_IS_WIDGET (action))
     action = create_action ();
-    
+
   gtk_entry_set_text (GTK_ENTRY (action_command_entry), get_command (nbr));
   gtk_entry_set_position (GTK_ENTRY (action_command_entry), 0);
   if (nbr < NBSELECTS)
-    {
-      set_choice_value (nbr);
-      gtk_widget_show (action_icon_label);
-      gtk_widget_show (action_icon_optionmenu);
-      gtk_widget_show (action_icon_browse_button);
-    }
+  {
+    set_choice_value (nbr);
+    gtk_widget_show (action_icon_label);
+    gtk_widget_show (action_icon_optionmenu);
+    gtk_widget_show (action_icon_browse_button);
+  }
   else
-    {
-      gtk_widget_hide (action_icon_label);
-      gtk_widget_hide (action_icon_optionmenu);
-      gtk_widget_hide (action_icon_browse_button);
-    }
-  action_signal_id1 =
-    gtk_signal_connect (GTK_OBJECT (action_ok_button), "clicked",
-			GTK_SIGNAL_FUNC (action_ok_cb), 
-                        (gpointer)((long) nbr));
-  action_signal_id2 =
-    gtk_signal_connect (GTK_OBJECT (action_icon_browse_button), "clicked",
-			GTK_SIGNAL_FUNC (action_browse_icon_cb),
-			(gpointer)((long) nbr));
+  {
+    gtk_widget_hide (action_icon_label);
+    gtk_widget_hide (action_icon_optionmenu);
+    gtk_widget_hide (action_icon_browse_button);
+  }
+  action_signal_id1 = gtk_signal_connect (GTK_OBJECT (action_ok_button), "clicked", GTK_SIGNAL_FUNC (action_ok_cb), (gpointer) ((long) nbr));
+  action_signal_id2 = gtk_signal_connect (GTK_OBJECT (action_icon_browse_button), "clicked", GTK_SIGNAL_FUNC (action_browse_icon_cb), (gpointer) ((long) nbr));
   gtk_window_set_modal (GTK_WINDOW (action), TRUE);
   gnome_sticky (action->window);
   gtk_widget_show (action);
