@@ -21,6 +21,8 @@
 #endif
 
 #include <stdio.h>
+#include <unistd.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
@@ -28,7 +30,6 @@
 #include <fcntl.h>
 #include <ctype.h>
 #include <sys/types.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
@@ -61,14 +62,16 @@
 #include "diagnostic.h"
 #include "my_tooltips.h"
 
+#ifndef HAVE_SNPRINTF
+#  include "snprintf.h"
+#endif
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
 
 extern gint check_mail (gpointer data);
 
-char **g_argv;
-
 void
 reap (int sig)
 {
@@ -88,11 +91,18 @@ main (int argc, char *argv[])
 {
   char gtkrc_file[MAXSTRLEN + 1];
   static int dg;
-
-  g_argv = argv;
+  char *homedir;
 
   xfce_init (&argc, &argv);
 
+  /* Build path to gtkrc file in user's home directory */
+  if (!(homedir = getenv ("HOME")))
+    {
+      fprintf (stderr, "Can't fetch $HOME. Aborting\n");
+      exit (-1);
+    }
+  snprintf (gtkrc_file, MAXSTRLEN, "%s/.gtkrc", (char *) homedir);
+
   signal (SIGCHLD, reap);
 
   /* The GC for the outline move */
@@ -132,21 +142,20 @@ main (int argc, char *argv[])
   update_gxfce_screen_buttons (current_config.visible_screen);
   gnome_set_desk_count (current_config.visible_screen ? current_config.visible_screen : 1);
   update_gxfce_popup_buttons (current_config.visible_popup);
-  update_gxfce_coord (gxfce, &current_config.panel_x,
-		      &current_config.panel_y);
   update_gxfce_size ();
+  update_gxfce_coord (gxfce, &current_config.panel_x, &current_config.panel_y);
   update_delay_tooltips (current_config.tooltipsdelay);
   update_gxfce_clock ();
-  gtk_widget_set_uposition (gxfce, current_config.panel_x,
-			    current_config.panel_y);
+  gtk_widget_set_uposition (gxfce, current_config.panel_x, current_config.panel_y);
 
   gtk_widget_show (gxfce);
   gnome_sticky (gxfce->window);
 
+  gnome_layer (gxfce->window, current_config.panel_layer);
+
   if (!current_config.wm)
     gnome_set_root_event (GTK_SIGNAL_FUNC (handle_gnome_workspace_event_cb));
 
-
   switch_to_screen (pal, 0);
   cursor_wait (gxfce);
   init_watchpipe ();
@@ -154,44 +163,38 @@ main (int argc, char *argv[])
   reg_xfce_app (gxfce, pal);
   close_startup (startup);
 
-  /* Build path to gtkrc file in user's home directory */
-  strcpy (gtkrc_file, (char *) getenv ("HOME"));
-  strcat (gtkrc_file, "/.gtkrc");
-
   /* Update all running GTK+ apps if ~/.gtkrc is not present */
 
   if (!existfile (gtkrc_file))
-    {
-      create_gtkrc_file (pal, NULL);
-      applypal_to_all ();
-    }
+  {
+    create_gtkrc_file (pal, NULL);
+    applypal_to_all ();
+  }
 
   /* Apply user's preferences to the Window Manager */
 
   if (current_config.wm == XFWM)
-    {
-      apply_wm_colors (pal);
-      apply_wm_fonts ();
-      apply_wm_iconpos ();
-      apply_wm_options ();
-      apply_wm_snapsize ();
-      startup_wm_modules ();
-    }
+  {
+    apply_wm_colors (pal);
+    apply_wm_fonts ();
+    apply_wm_iconpos ();
+    apply_wm_options ();
+    apply_wm_snapsize ();
+    apply_wm_engine ();
+    startup_wm_modules ();
+  }
 
-   /* Initialize the pipe for subprocess diagnostics */
-   dg = initdiag ();
-   
-   /* And display the diag box every time a message comes out */
-   gdk_input_add (dg,
-		  GDK_INPUT_READ,
-		  (GdkInputFunction) process_diag_messages,
-		  (gpointer) ((long) dg));
+  /* Initialize the pipe for subprocess diagnostics */
+  dg = initdiag ();
+
+  /* And display the diag box every time a message comes out */
+  gdk_input_add (dg, GDK_INPUT_READ, (GdkInputFunction) process_diag_messages, (gpointer) ((long) dg));
 
   /* Add a hook for the mail-check function. */
   gtk_timeout_add (MAILCHECK_PERIOD, check_mail, NULL);
 
   cursor_reset (gxfce);
-  
+
   /* Main event loop */
   gtk_main ();
 
@@ -199,6 +202,8 @@ main (int argc, char *argv[])
   signal (SIGCHLD, SIG_DFL);
   free_selects ();
   free_tooltips_list ();
+  free_internals_setup ();
+
   quit_wm ();
   FreeDrawGC ();
 
