@@ -23,10 +23,8 @@
 
 GtkWidget *clock_popup_menu;
 
-GtkWidget *
-clock_make_popup (MyGtkClock *);
+GtkWidget *clock_make_popup (MyGtkClock *);
 
-GtkWidget*
-create_menu (MyGtkClock *);
+GtkWidget *create_menu (MyGtkClock *);
 
 #endif
