@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -25,5 +27,5 @@
 #ifndef __GTK_GET_H__
 #define __GTK_GET_H__
 
-int download (uri *, char *);
+int download (char *tgt, char *src);
 #endif
