@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -25,6 +27,10 @@
 #ifndef __XTREE_CFG_H__
 #define __XTREE_CFG_H__
 
+#include <gtk/gtk.h>
+#include "xtree_mess.h"
+#include "xtree_go.h"
+
 #define IGNORE_HIDDEN 1
 
 typedef struct
@@ -34,13 +40,25 @@ typedef struct
   char *xap;			/* xap home-dir, default: $HOME/.xap */
   GList *reg;			/* registered programs */
   int dnd_row;
-  void *dnd_menu;
   char *dnd_data;
-  int dnd_has_drag;
   int timer;
   /* geometry */
   int width;
   int height;
+  GtkWidget *restore_menu;
+  GtkWidget *top;
+  GtkWidget *toolbar;
+  GtkWidget *toolbarO;
+  GtkWidget *menu;
+  GtkWidget *filter;
+  GtkWidget *status;
+  GtkWidget *autotype_C;
+  GtkWidget *autotar_C;
+  GtkCTreeNode *status_node;
+  golist *gogo;
+  int filterOpts;
+  unsigned int preferences;
+  unsigned int stateTB[2];
 }
 cfg, cfg_t;
 
