@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -28,11 +30,9 @@
 #define ROW_TOP_YPIXEL(clist,row) (((clist)->row_height*(row))+\
 	(((row))+1)*1+(clist)->voffset)
 
-void on_drag_data (GtkWidget * ctree, GdkDragContext * context, gint x,
-		   gint y, GtkSelectionData * data, guint info, guint itme,
-		   void *client);
+void on_drag_data (GtkWidget * ctree, GdkDragContext * context, gint x, gint y, GtkSelectionData * data, guint info, guint itme, void *client);
 
-void on_drag_data_get (GtkWidget * widget, GdkDragContext * context,
-		       GtkSelectionData * selection_data, guint info,
-		       guint time, gpointer data);
+void on_drag_data_get (GtkWidget * widget, GdkDragContext * context, GtkSelectionData * selection_data, guint info, guint time, gpointer data);
+gboolean on_drag_motion (GtkWidget * widget, GdkDragContext * dc, gint x, gint y, guint t, gpointer data);
+void on_drag_end (GtkWidget * widget, GdkDragContext * dc, gpointer data);
 #endif
